@@ -11,7 +11,7 @@ __PACKAGE__->has_many(
 );
 __PACKAGE__->many_to_many(
     'tracks' => 'cd_tracks',
-    'trackid'
+    'track'
 );
 
 1;
